@@ -3,7 +3,7 @@
 import pytest
 import os
 
-from epivizFileParser.BigBed import BigBed
+from epivizFileParser import BigBed
 
 __author__ = "jkanche, elgaml"
 __copyright__ = "jkanche"
